@@ -1,64 +1,65 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="nl">
+<!DOCTYPE TS>
+<TS version="2.0" language="nl">
 <context>
     <name>ConfigWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="536"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="597"/>
         <source>Keep backlight on</source>
         <translation type="unfinished">Beeld niet dimmen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="538"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="599"/>
         <source>Wakeup screen on alarm</source>
         <translation type="unfinished">Scherm aan bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="539"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="600"/>
         <source>Vibrate on alarm</source>
         <translation type="unfinished">Tril bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="540"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="601"/>
         <source>Sound on alarm</source>
         <translation type="unfinished">Geluid bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="541"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="602"/>
         <source>Alarm banner</source>
         <translation type="unfinished">Alarm tekst</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="562"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="623"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="574"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="635"/>
         <source>Alarm volume: </source>
         <translation type="unfinished">Alarm volume:</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="588"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="649"/>
         <source>Alarm volume: max</source>
         <translation type="unfinished">Alarm volume: max</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="577"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="638"/>
         <source>Alarm muted</source>
         <translation type="unfinished">Stil alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="618"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="679"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="623"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="684"/>
         <source>Could NOT save Configuration!</source>
         <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="522"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="583"/>
         <source>Configuration cooktimer</source>
         <translation type="unfinished">Configuratie cooktimer</translation>
     </message>
@@ -66,7 +67,7 @@
 <context>
     <name>DishPickDialog</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2598"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2969"/>
         <source>[Choose dish]</source>
         <translation type="unfinished">[Kies gerecht]</translation>
     </message>
@@ -74,113 +75,181 @@
 <context>
     <name>FormWidget</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1849"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2178"/>
         <source>timer 2 ready!</source>
         <translation type="unfinished">timer 2 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1941"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2276"/>
         <source>Start</source>
         <translation type="unfinished">Start</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1367"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1428"/>
         <source>Choose dish</source>
         <translation type="unfinished">Kies gerecht</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1763"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2091"/>
         <source>timer 1 ready!</source>
         <translation type="unfinished">timer 1 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1933"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2265"/>
         <source>timer 3 ready!</source>
         <translation type="unfinished">timer 3 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1688"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2015"/>
         <source>Stop</source>
         <translation type="unfinished">Stop</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1476"/>
-        <source>Stopwatch activated</source>
-        <translation type="unfinished">Stopwatch geactiveerd</translation>
+        <location filename="src/opt/cooktimer/cooktimer" line="1741"/>
+        <source>Stopwatch mode ON</source>
+        <translation type="unfinished">Stopwatch mode AAN</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1478"/>
-        <source>Stopwatch deactivated</source>
-        <translation type="unfinished">Stopwatch gedeactiveerd</translation>
+        <location filename="src/opt/cooktimer/cooktimer" line="1789"/>
+        <source>Stopwatch mode OFF</source>
+        <translation type="unfinished">Stopwatch mode UIT</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="1564"/>
+        <source>Continue mode ON</source>
+        <translation type="unfinished">Vervolg mode AAN</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="1569"/>
+        <source>Continue mode OFF</source>
+        <translation type="unfinished">Vervolg mode UIT</translation>
+    </message>
+</context>
+<context>
+    <name>HelpWindow</name>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="532"/>
+        <source>Help</source>
+        <translation type="unfinished">Help</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="549"/>
+        <source>Cooktimer</source>
+        <translation type="unfinished">Cooktimer</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="552"/>
+        <source>Apart from the obvious functions and settings, there are some not so easily spotted:</source>
+        <translation type="unfinished">Naast de vanzelfsprekende functies en instellingen, zijn er een aantal niet zo makkelijk te herkennen:</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="554"/>
+        <source>Pressing a running timer bar will pause the alarm</source>
+        <translation type="unfinished">Het aanraken van de tijdsbalk zal de klok pauzeren</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="555"/>
+        <source>Pressing a paused timer bar will unpause the alarm</source>
+        <translation type="unfinished">Het aanraken van de gepauzeerde tijdsbalk zal de klok hervatten</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="556"/>
+        <source>Pressing a timer bar after showing &quot;00:00:00&quot; will silence it&apos;s alarm</source>
+        <translation type="unfinished">Door op de tijdsbalk te drukken waarbij het alarm afgaat, zal het alarmsignaal stoppen</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="557"/>
+        <source>Long-pressing a timepicker will switch to stopwatch mode</source>
+        <translation type="unfinished">Het lang indrukken van de tijd selector zal de stopwatch mode aanzetten</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="558"/>
+        <source>Long-pressing a timer bar will (de)activate continue mode</source>
+        <translation type="unfinished">Het lang indrukken van de tijdsbalk zal de &quot;vervolg-mode&quot; (de)activeren</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="559"/>
+        <source>By pushing the add icon in the &quot;edit dishes&quot; menu you can set interim messages and make it preload at startup</source>
+        <translation type="unfinished">Via het plus icoon in &quot;Bewerk gerechten&quot; kan men tussentijdse berichten zetten en automatisch met het gerecht opstarten</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="550"/>
+        <source>Cooktimer provides three timers for preparing the perfect meal.</source>
+        <translation type="unfinished">Cooktimer biedt drie timers om een perfecte maaltijd te bereiden.</translation>
     </message>
 </context>
 <context>
     <name>MyMainWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="369"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="373"/>
         <source>&amp;About</source>
         <translation type="unfinished">&amp;Over</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="333"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="336"/>
         <source>&amp;Landscape</source>
         <translation type="unfinished">&amp;Landschap</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="335"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="338"/>
         <source>&amp;Portrait</source>
         <translation type="unfinished">&amp;Portret</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="337"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="340"/>
         <source>&amp;Autorotate</source>
         <translation type="unfinished">&amp;Autorotatie</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="343"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="346"/>
         <source>&amp;Settings</source>
         <translation type="unfinished">&amp;Instellingen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="367"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="370"/>
         <source>&amp;Edit dishes</source>
         <translation type="unfinished">&amp;Bewerk gerechten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="368"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="371"/>
         <source>&amp;Custom alarm sound</source>
         <translation type="unfinished">&amp;Alarm geluid</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="511"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="521"/>
         <source>About</source>
         <translation type="unfinished">Over</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="514"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="524"/>
         <source>Created by</source>
         <translation type="unfinished">Gemaakt door</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="472"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="482"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="477"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="487"/>
         <source>Could NOT save Configuration!</source>
         <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
     </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="372"/>
+        <source>&amp;Help</source>
+        <translation type="unfinished">&amp;Help</translation>
+    </message>
 </context>
 <context>
     <name>TimePickDialog</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2451"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2822"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2450"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2821"/>
         <source>| hours | minutes | seconds |</source>
         <translation type="unfinished">| uren | minuten | seconden |</translation>
     </message>
@@ -188,42 +257,42 @@
 <context>
     <name>extItemWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2698"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3069"/>
         <source>Message</source>
         <translation type="unfinished">Bericht</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2704"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3075"/>
         <source>time</source>
         <translation type="unfinished">tijd</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2742"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3113"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2689"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3060"/>
         <source>set on start</source>
         <translation type="unfinished">bij opstarten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2737"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3108"/>
         <source>Alarm</source>
         <translation type="unfinished">Alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2844"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3215"/>
         <source>Message time larger then alarm time!</source>
         <translation type="unfinished">Bericht na alarmtijd!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2905"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3276"/>
         <source>Max of 3 presets already used!</source>
         <translation type="unfinished">Max van 3 presets al gebruikt!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2921"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3292"/>
         <source>Messages are successfully saved</source>
         <translation type="unfinished">Berichten succesvol opgeslagen</translation>
     </message>
@@ -231,17 +300,17 @@
 <context>
     <name>fileWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="920"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="981"/>
         <source>Choose soundfile</source>
         <translation type="unfinished">Kies geluidsfragment</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1047"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1108"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1052"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1113"/>
         <source>Could NOT save Configuration!</source>
         <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
     </message>
@@ -249,27 +318,27 @@
 <context>
     <name>itemWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="707"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="768"/>
         <source>Dish cooktimes</source>
         <translation type="unfinished">Gerecht kooktijden</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="735"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="796"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="736"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="797"/>
         <source>New</source>
         <translation type="unfinished">Nieuw</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="884"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="945"/>
         <source>time</source>
         <translation type="unfinished">tijd</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="875"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="936"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
